"""Neuromation auth client."""
from pkg_resources import get_distribution

from .api import check_permissions
from .client import (
    AuthClient,
    ClientAccessSubTreeView,
    ClientSubTreeViewRoot,
    Cluster,
    Permission,
    Quota,
    User,
)


__all__ = [
    "AuthClient",
    "ClientAccessSubTreeView",
    "ClientSubTreeViewRoot",
    "Cluster",
    "Permission",
    "Quota",
    "User",
    "check_permissions",
]
__version__ = get_distribution(__name__).version



from setuptools import find_packages, setup


install_requires = (
    "aiohttp>=3.4.3",
    "aiohttp-security>=0.4.0",
    "python-jose>=3.0.1",
)

setup(
    name="neuro-auth-client",
    use_scm_version=True,
    url="https://github.com/neuro-inc/neuro-auth-client",
    packages=find_packages(),
    python_requires=">=3.8",
    install_requires=install_requires,
    setup_requires=["setuptools_scm"],
    zip_safe=False,
    include_package_data=True,
)
